@@ -591,6 +591,13 @@ class PlottingTests(unittest.TestCase):
         plt.title("testing kmf flat styling + marker")
         return
 
+    def test_flat_style_no_censor(self):
+        data1 = np.random.exponential(10, size=200)
+        kmf = KaplanMeierFitter()
+        kmf.fit(data1,label='test label 1')
+        ax = kmf.plot(flat=True, censor_styles={'marker':'+', 'mew':2, 'ms':7})
+        return
+
 
 
 # some data
@@ -598,169 +605,11 @@ LIFETIMES = np.array([2, 4, 4, 4, 5, 7, 10, 11, 11, 12])
 CENSORSHIP = np.array([1, 1, 0, 1, 0, 1, 1, 1, 1, 0])
 N = len(LIFETIMES)
 
-waltonT2 = np.array([6.,
-                     13.,
-                     13.,
-                     13.,
-                     19.,
-                     19.,
-                     19.,
-                     26.,
-                     26.,
-                     26.,
-                     26.,
-                     26.,
-                     33.,
-                     33.,
-                     47.,
-                     62.,
-                     62.,
-                     9.,
-                     9.,
-                     9.,
-                     15.,
-                     15.,
-                     22.,
-                     22.,
-                     22.,
-                     22.,
-                     29.,
-                     29.,
-                     29.,
-                     29.,
-                     29.,
-                     36.,
-                     36.,
-                     43.])
-waltonT1 = np.array([33.,
-                     54.,
-                     54.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     61.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     69.,
-                     32.,
-                     53.,
-                     53.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     68.,
-                     75.,
-                     17.,
-                     51.,
-                     51.,
-                     51.,
-                     58.,
-                     58.,
-                     58.,
-                     58.,
-                     66.,
-                     66.,
-                     7.,
-                     7.,
-                     41.,
-                     41.,
-                     41.,
-                     41.,
-                     41.,
-                     41.,
-                     41.,
-                     48.,
-                     48.,
-                     48.,
-                     48.,
-                     48.,
-                     48.,
-                     48.,
-                     48.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     56.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     63.,
-                     69.,
-                     69.,
-                     38.,
-                     38.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     45.,
-                     53.,
-                     53.,
-                     53.,
-                     53.,
-                     53.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     60.,
-                     66.])
+waltonT = np.array([6.,13.,13.,13.,19.,19.,19.,26.,26.,26.,26.,26.,33.,33.,47.,62.,62.,9.,9.,9.,15.,15.,22.,22.,22.,22.,29.,29.,29.,29.,29.,36.,36.,43.])
+waltonT = np.array([33.,54.,54.,61.,61.,61.,61.,61.,61.,61.,61.,61.,61.,61.,69.,69.,69.,69.,69.,69.,69.,69.,69.,69.,69.,32.,53.,53.,60.,60.,60.,60.,60.,
+                        68.,68.,68.,68.,68.,68.,68.,68.,68.,68.,75.,17.,51.,51.,51.,58.,58.,58.,58.,66.,66.,7.,7.,41.,41.,41.,41.,41.,41.,41.,48.,48.,48.,
+                        48.,48.,48.,48.,48.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,56.,63.,63.,63.,63.,63.,63.,63.,63.,63.,69.,
+                        69.,38.,38.,45.,45.,45.,45.,45.,45.,45.,45.,45.,45.,53.,53.,53.,53.,53.,60.,60.,60.,60.,60.,60.,60.,60.,60.,60.,60.,66.])
 
 waltonG = np.array(['miR-137', 'miR-137', 'miR-137', 'miR-137', 'miR-137', 'miR-137',
                     'miR-137', 'miR-137', 'miR-137', 'miR-137', 'miR-137', 'miR-137',
